==> cmdopt-0.1.0.tgz: package/Kookbook.py <==
###
### $Release: 0.1.0 $
### $Copyright: copyright(c) 2011 kuwata-lab.com all rights reserved $
### $License: MIT License $
###
from __future__ import with_statement

import sys, os, re
from kook.utils import glob2


kookbook.default = 'test'


vs_home = os.getenv('VS_PATH').split(':')[0]
nodejs_executables = [
    ("0.4", "%s/node/0.4.11/bin/node" % vs_home),
    ("0.5", "%s/node/0.5.10/bin/node" % vs_home),
    ("0.6", "%s/node/0.6.3/bin/node"  % vs_home),
]


class test(Category):

    @recipe
    def default(c):
        """do test"""
        for fname in glob2('test/**/*_test.js'):
            system_f(c%"node $(fname)")

    @recipe
    def all(c):
        """do test on Node.js 0.4, 0.5, and 0.6"""
        for ver, bin in nodejs_executables:
            print("******************** Node.js %s ********************" % ver)
            for fname in glob2('test/**/*_test.js'):
                system_f(c%"$(bin) $(fname)")


kookbook.load('@kook/books/clean.py')
CLEAN.extend(('README.html', 'dist'))


target_files = [
    'README.rst', 'MIT-LICENSE', 'Kookbook.py', 'package.json', '.gitignore',
    'cmdopt.js', 'test/**/*.js', 'examples/**/*',
]


class pkg(Category):

    @recipe
    @ingreds('clean')
    def default(c):
        """show steps to release"""
        print("""
bash> git status
bash> git commit -a
bash> kk test:all
bash> kk pkg:check
bash> git co -b js-X.X  # or git co js-X.X
bash> vi README.rst     # update history
bash> kk pkg:dist X.X.X
bash> #(cd dist/X.X.X; kk test:all)
bash> git tag js-X.X.X
bash> (cd dist/X.X.X; npm publish)
bash> (cd wiki; git commit -a; git push)
"""[1:])

    #@recipe
    #@ingreds('wiki/Cmdopt.js.wiki', 'clean')
    #@spices('release')
    #def task_edit(c, *args):
    #    replacer = [
    #        (r'\$(Release): .*? \$', c%'$\\1: $(release) $'),
    #        (r'\$(Release)\$', release)
    #        #(r'\$(License): .*? \$', c%'$\\1: $(license) $'),
    #        #(r'\$(Copyright): .*? \$', c%'$\\1: $(copyright) $'),
    #    ]
    #    edit(target_files, by=replacer)

    @recipe
    @ingreds('wiki/Cmdopt.js.wiki', 'clean')
    @spices('release')
    def dist(c, *args):
        release = args[0]
        if not release:
            raise Exception("dist: release number required.")
        """create 'dist' directory and copy files into it"""
        dir = c%'dist/$(release)'
        rm_rf(dir)
        mkdir_p(dir)
        files = ['README.rst', 'MIT-LICENSE', 'Kookbook.py', 'package.json', '.gitignore']
        store(files, dir)
        store('cmdopt.js', 'test/**/*_test.js', 'examples/**/*', dir)
        #
        replacer = [
            (r'\$(Release):.*?\$', c%'$\\1: $(release) $'),
            (r'\$(Release)\$', release)
            #(r'\$(License): .*? \$', c%'$\\1: $(license) $'),
            #(r'\$(Copyright): .*? \$', c%'$\\1: $(copyright) $'),
        ]
        edit(c%"$(dir)/**/*", c.ingred, by=replacer)
        #
        system(c%"find $(dir)")

    @recipe
    def check(c):
        code = r"""
'use strict';
var fs = require("fs");
var s = fs.readFileSync('package.json', 'utf-8');
var json = JSON.parse(s);
//console.log(json);
"""[1:]
        with open("_check.js", "w") as f: f.write(code)
        try:
            system("node _check.js");
        finally:
            os.unlink("_check.js")


@recipe
@ingreds('wiki/Cmdopt.js.wiki')
def wiki(c):
    pass

@recipe('README.html')
def file_README_html(c):
    system("rst2html.py README.rst > README.html")
    #system("rst2html.py --strip-elements-with-class='section' README.rst > README.html")
    #system("rst2html.py --strip-class='literal-block' README.rst > README.html")

@recipe('wiki/Cmdopt.js.wiki', ['README.html'])
def file_wiki_Cmdopt_js_wiki(c):
    import codecs
    with codecs.open("README.html", encoding='utf-8') as f:
        html = f.read()
    assert isinstance(html, unicode)
    from creole import html2creole
    html = clean_html(html)
    wiki = html2creole(html)
    wiki = beautify_wiki(wiki)
    with codecs.open(c.product, 'w', encoding='utf-8') as f:
        f.write(wiki)
    system(c%"cat $(product) | pbcopy")

def clean_html(html):
    beg = html.find('<body>') + len('<body>')
    end = html.rfind('</body>')
    html = html[beg:end]
    html = re.sub(r'<div(?: .*?)?>', '', html)
    html = re.sub(r'</div>', '', html)
    html = re.sub(r'<pre .*?>', '<pre>', html)
    html = re.sub(r'([^\n])(</pre>)', '\\1\n\\2', html)
    def fn(m):
        n = int(m.group(1)) + 1
        return r'<h%s>%s</h%s>' % (n, m.group(2), n)
    html = re.sub(r'<h(\d)>(.*?)</h\1>', fn, html)
    return html

def beautify_wiki(wiki):
    wiki = re.sub(r'\}\}\}\n', "}}}\n\n", wiki)
    wiki = re.compile(r'^==', re.M).sub("\n==", wiki)
    return wiki

==> cmdopt-0.2.0.tgz: package/Kookbook.py <==
###
### $Release: 0.2.0 $
### $Copyright: copyright(c) 2011 kuwata-lab.com all rights reserved $
### $License: MIT License $
###
from __future__ import with_statement

import sys, os, re
from kook.utils import glob2


kookbook.default = 'test'


release = prop('release', '0.2.0')


vs_home = os.getenv('VS_PATH').split(':')[0]
nodejs_executables = [
    ("0.4", "%s/node/0.4.11/bin/node" % vs_home),
    ("0.5", "%s/node/0.5.10/bin/node" % vs_home),
    ("0.6", "%s/node/0.6.3/bin/node"  % vs_home),
]


class test(Category):

    @recipe
    def default(c):
        """do test"""
        for fname in glob2('test/**/*_test.js'):
            system_f(c%"node $(fname)")

    @recipe
    def all(c):
        """do test on Node.js 0.4, 0.5, and 0.6"""
        for ver, bin in nodejs_executables:
            print("******************** Node.js %s ********************" % ver)
            for fname in glob2('test/**/*_test.js'):
                system_f(c%"$(bin) $(fname)")


kookbook.load('@kook/books/clean.py')
CLEAN.extend(('README.html', 'dist'))


target_files = [
    'README.txt', 'MIT-LICENSE', 'Kookbook.py', 'package.json', '.gitignore',
    'cmdopt.js', 'test/**/*.js', 'examples/**/*',
]


class pkg(Category):

    @recipe
    @ingreds('clean')
    def default(c):
        """show steps to release"""
        print("""
bash> git status
bash> git commit -a
bash> kk test:all
bash> kk pkg:check
bash> git co -b js-X.X  # or git co js-X.X
bash> vi README.txt     # update history
bash> vi Kookbook.py    # increment release number
bash> git ci -am "release preparation for X.X.X"
bash> git tag js-X.X.X
bash> kk pkg:dist
bash> #(cd dist/X.X.X; kk test:all)
bash> (cd dist/X.X.X; npm publish)
bash> (cd wiki; git commit -a; git push)
"""[1:])

    #@recipe
    #@ingreds('wiki/Cmdopt.js.wiki', 'clean')
    #def task_edit(c, *args):
    #    replacer = [
    #        (r'\$(Release): .*? \$', c%'$\\1: $(release) $'),
    #        (r'\$(Release)\$', release)
    #        #(r'\$(License): .*? \$', c%'$\\1: $(license) $'),
    #        #(r'\$(Copyright): .*? \$', c%'$\\1: $(copyright) $'),
    #    ]
    #    edit(target_files, by=replacer)

    @recipe
    @ingreds('wiki/Cmdopt.js.wiki', 'clean')
    def dist(c, *args):
        """create 'dist' directory and copy files into it"""
        dir = c%'dist/$(release)'
        rm_rf(dir)
        mkdir_p(dir)
        files = ['README.txt', 'MIT-LICENSE', 'Kookbook.py', 'package.json', '.gitignore']
        store(files, dir)
        store('cmdopt.js', 'test/**/*_test.js', 'examples/**/*', dir)
        #
        replacer = [
            (r'\$(Release):.*?\$', c%'$\\1: $(release) $'),
            (r'\$(Release)\$', release)
            #(r'\$(License): .*? \$', c%'$\\1: $(license) $'),
            #(r'\$(Copyright): .*? \$', c%'$\\1: $(copyright) $'),
        ]
        edit(c%"$(dir)/**/*", c.ingred, by=replacer)
        #
        system(c%"find $(dir)")

    @recipe
    def check(c):
        code = r"""
'use strict';
var fs = require("fs");
var s = fs.readFileSync('package.json', 'utf-8');
var json = JSON.parse(s);
//console.log(json);
"""[1:]
        with open("_check.js", "w") as f: f.write(code)
        try:
            system("node _check.js");
        finally:
            os.unlink("_check.js")


###
### wiki
###
kookbook.load('./books/wiki.py');


@recipe('README.html')
def file_README_html(c):
    system("rst2html.py README.txt > README.html")
    #system("rst2html.py --strip-elements-with-class='section' README.txt > README.html")
    #system("rst2html.py --strip-class='literal-block' README.txt > README.html")
